@@ -1,3 +1,10 @@
+# Created by Jon Zink  (jzink@astro.ucla.edu)
+# Developed with python 3.7.1
+#
+# If you make use of this code, please cite:
+# J. K. Zink et al. 2020a
+
+
 import EDIunplugged.metrics as ediMet
 import EDIunplugged.version as version
 import warnings
@@ -31,7 +38,7 @@ class parameters(object):
         # Working with the parameters
     
         >>> params=EDI_Vetter.paramaters(tlsOut, limbDark=[0.48, 0.19], impact=0, snrThreshold=7, minTransit=3)
-        >>> params=EDI_Vetter.Go(params, delta_mag=2.7, delta_dist=1000, photoAp=25, telescope="Kepler")
+        >>> params=EDI_Vetter.Go(params, deltaMag=2.7, deltaDist=1000, photoAp=25, telescope="Kepler", )
 
     """
     
@@ -55,10 +62,41 @@ class parameters(object):
             print("WARNING: assuming default impact parameter value")
             self.impact=0
                
+def prettyPrint(params):
+    print("""
+ ___________ _____      _   _      _   _
+|  ___|  _  \_   _|    | | | |    | | | |
+| |__ | | | | | |______| | | | ___| |_| |_ ___ _ __
+|  __|| | | | | |______| | | |/ _ \ __| __/ _ \ '__|
+| |___| |/ / _| |_     \ \_/ /  __/ |_| ||  __/ |
+\____/|___/  \___/      \___/ \___|\__|\__\___|_|   Unplugged
+    """)
+    print("Version "
+        + version.EDI_VERSIONING
+        + " ("
+        + version.EDI_DATE
+        + ")"
+        )
+    print("==========================================")
+    print("            Vetting Report") 
+    print("==========================================")   
+    print("        Flux Contamination : " + str(params.fluxContamFP))        
+    print("         Too Many Outliers : " + str(params.outlierTranFP))
+    print("  Too Many Transits Masked : " + str(params.transMaskFP))   
+    print("Odd/Even Transit Variation : " + str(params.evenOddFP))   
+    print("      Signal is not Unique : " + str(params.uniqueFP))
+    print("   Secondary Eclipse Found : " + str(params.secEclipseFP))
+    # print(" Transit Mid-point Slipped : " + str(params.eph_slipFP))
+    # print("     Strong Harmonic Found : " + str(params.harmonicFP))
+    print("Low Transit Phase Coverage : " + str(params.phaseCoverFP) )
+    print(" Transit Duration Too Long : " + str(params.tranDurFP))
+    print("==========================================") 
+    print("Signal is a False Positive : "+  str(params.FalsePositive))
+
           
 
 
-def Go(params,delta_mag=float("Inf"),delta_dist=float("Inf"), photoAp=1, telescope=None):
+def Go(params, deltaMag=float("Inf"), deltaDist=float("Inf"), photoAp=1, telescope=None, print=True):
     """Initialize All Vetting Metrics.
 
     The Go function runs all of the EDI-Vetter metrics on the transit signal.  
@@ -67,16 +105,18 @@ def Go(params,delta_mag=float("Inf"),delta_dist=float("Inf"), photoAp=1, telesco
         params (Required[object]): the transit parameters needed to assess
              the validity of the signal
         
-        delta_mag (optional[float]): magnitude difference between target star
+        deltaMag (optional[float]): magnitude difference between target star
              and potential contaminate source in the Gaia G band
         
-        delta_dist (optional[float]): distance between the target star and the
+        deltaDist (optional[float]): distance between the target star and the
              potential contaminate source in arc-seconds
         
         photoAp (optional[int]): number of pixels used for the target aperture
     
         telescope (optional[string]): name of telescope data was collected from 
-            (i.e. "Kepler", "K2", or "TESS")
+            (i.e., "Kepler", "K2", or "TESS")
+    
+        print (optional[boolean]): do you want EDI to print out the results
     
     Output:
         params : the modified transit parameters needed to assess
@@ -99,57 +139,30 @@ def Go(params,delta_mag=float("Inf"),delta_dist=float("Inf"), photoAp=1, telesco
         pxScale=3.98       
 
     params.FalsePositive=False
-        #############   Run EDI-Vetter   ########
-        ############# Exoplanet Detection Indicator - Vetter ######
-
-    print("""
- ___________ _____      _   _      _   _            
-|  ___|  _  \_   _|    | | | |    | | | |           
-| |__ | | | | | |______| | | | ___| |_| |_ ___ _ __ 
-|  __|| | | | | |______| | | |/ _ \ __| __/ _ \ '__|
-| |___| |/ / _| |_     \ \_/ /  __/ |_| ||  __/ |   
-\____/|___/  \___/      \___/ \___|\__|\__\___|_|   Unplugged
-    """)
-    print("Version "
-        + version.EDI_VERSIONING
-        + " ("
-        + version.EDI_DATE
-        + ")"
-    )
-    params=ediMet.fluxContamination(params,delta_mag,delta_dist, photoAp,pxScale)
-    params=ediMet.outlierTransit(params)
-    params=ediMet.individual_transits(params)
-    params=ediMet.even_odd_transit(params)
-    params=ediMet.uniqueness_test(params)
+    
+#############   Run EDI-Vetter Unplugged  ########
+############# Exoplanet Detection Indicator - Vetter ######
+            
+    params=ediMet.fluxContam(params, deltaMag, deltaDist, photoAp,pxScale)
+    params=ediMet.outlierTran(params)
+    params=ediMet.transMask(params)
+    params=ediMet.evenOdd(params)
+    params=ediMet.unique(params)
     # params=ephemeris_wonder(params)
-    params=ediMet.check_SE(params)
+    params=ediMet.secEclipse(params)
     # params=harmonic_test(params)
     # params=period_alias(params,cycle=True)
-    params=ediMet.phase_coverage(params)
-    params=ediMet.tdur_max(params)
+    params=ediMet.phaseCover(params)
+    params=ediMet.tranDur(params)
     
-    if params.fluxContaminationFP | params.outlierTransitFP | params.TransMaskFP | params.even_odd_transit_misfit | params.uniquenessFP | params.SeFP | params.phaseCoverFP | params.tdurFP :
+    if params.fluxContamFP | params.outlierTranFP| params.transMaskFP | params.evenOddFP | params.uniqueFP | params.secEclipseFP | params.phaseCoverFP | params.tranDurFP :
         params.FalsePositive=True
     else:
         params.FalsePositive=False
-    
-    print("==========================================")
-    print("            Vetting Report") 
-    print("==========================================")   
-    print("        Flux Contamination : " + str(params.fluxContaminationFP))        
-    # print("         Too Many Outliers : " + str(params.outlierTransitFP))
-    print("  Too Many Transits Masked : " + str(params.TransMaskFP))   
-    print("Odd/Even Transit Variation : " + str(params.even_odd_transit_misfit))   
-    print("      Signal is not Unique : " + str(params.uniquenessFP))
-    print("   Secondary Eclipse Found : " + str(params.SeFP))
-    # print(" Transit Mid-point Slipped : " + str(params.eph_slipFP))
-    # print("     Strong Harmonic Found : " + str(params.harmonicFP))
-    print("Low Transit Phase Coverage : " + str(params.phaseCoverFP) )
-    print(" Transit Duration Too Long : " + str(params.tdurFP))
-    print("==========================================") 
-    print("Signal is a False Positive : "+  str(params.FalsePositive))
-             
         
+    if print==True:
+        prettyPrint(params)
+                 
     return params
     
 
