@@ -1,8 +1,15 @@
+# Created by Jon Zink  (jzink@astro.ucla.edu)
+# Developed with python 3.7.1
+#
+# If you make use of this code, please cite:
+# J. K. Zink et al. 2020a
+
+
 import numpy as np
 from astropy.stats import mad_std
 from scipy import special
 
-def fluxContamination(params,delta_mag,delta_dist, photoAp, pxScale):
+def fluxContam(params,delta_mag,delta_dist, photoAp, pxScale):
     """Flux Contamination test
     Look for transit contamination from nearby stars.
     
@@ -36,16 +43,16 @@ def fluxContamination(params,delta_mag,delta_dist, photoAp, pxScale):
     #     params.fluxContaminationFP=True
     
     if (fit_rp*np.sqrt(fTotStar) + fit_b)>1.04:
-        params.fluxContaminationFP=True
+        params.fluxContamFP=True
         
     elif (fit_rp)*np.sqrt(fTotStar)>0.3:
-        params.fluxContaminationFP=True
+        params.fluxContamFP=True
     else:
-        params.fluxContaminationFP=False
+        params.fluxContamFP=False
     
     return params
   
-def outlierTransit(params):
+def outlierTran(params):
     
     """Outlier Detection
      
@@ -75,13 +82,13 @@ def outlierTransit(params):
     noDepthsd=mad_std(foldY[(foldX<.5-tdur/per/2) | (foldX>.5+tdur/per/2)])
     
     if Depthsd>(0.4*mes-1.764)*noDepthsd:
-        params.outlierTransitFP=True
+        params.outlierTranFP=True
     else:
-        params.outlierTransitFP=False   
+        params.outlierTranFP=False   
         
     return params         
 
-def individual_transits(params):
+def transMask(params):
     
     """Individual Transit Test
      
@@ -113,36 +120,36 @@ def individual_transits(params):
 
             
     if nTr<params.minTransit:
-        params.TransMaskFP=True
+        params.transMaskFP=True
     else:
-        params.TransMaskFP=False
+        params.transMaskFP=False
 
     if (np.max(sESReal))>=(0.8*np.sqrt(3/params.minTransit)*np.sqrt(sEStot)):
-        params.TransMaskFP=True
+        params.transMaskFP=True
     else:
         pass
 
     if np.sqrt(sEStot)<params.snrThreshold:
-        params.TransMaskFP=True
+        params.transMaskFP=True
     else:
         pass                    
                 
     return params 
 
 
-def even_odd_transit(params):
+def evenOdd(params):
     
     eoSig=params.tlsOut.odd_even_mismatch
         
-    if params.tlsOut.transit_count>5:
-        params.even_odd_transit_misfit=True          
+    if eoSig>5:
+        params.evenOddFP=True          
     else:
-        params.even_odd_transit_misfit=False
+        params.evenOddFP=False
     
     return params
 
 
-def uniqueness_test(params):
+def unique(params):
     per=params.tlsOut.period
     tdur=params.tlsOut.duration
     falseAlarm=params.tlsOut.FAP
@@ -152,36 +159,38 @@ def uniqueness_test(params):
     #remove SE
     foldYnoSE=foldY[(foldX>tdur/per/2) | (foldX<1-tdur/per/2)]
     foldXnoSE=foldX[(foldX>tdur/per/2) | (foldX<1-tdur/per/2)]
-    #remvoe singal
+    #remvoe signal
     foldYnoSE=foldYnoSE[(foldXnoSE<.5-tdur/per/2) | (foldXnoSE>.5+tdur/per/2)]
     foldXnoSE=foldXnoSE[(foldXnoSE<.5-tdur/per/2) | (foldXnoSE>.5+tdur/per/2)]
 
-    signalTrue=np.mean(foldY[(foldX>=.5-tdur/per/2) & (foldX<=.5+tdur/per/2)])
+    signalTrue=1-np.mean(foldY[(foldX>=.5-tdur/per/2) & (foldX<=.5+tdur/per/2)])
     signal=np.zeros(len(foldYnoSE))
     
     for i in range(len(foldYnoSE)):
-        if foldX[i]<tdur/per:
-            signal[i]=np.mean(foldYnoSE[(foldXnoSE<foldXnoSE[i]+tdur/per/2)])
+        if foldX[i]<tdur/per/2:
+            signal[i]=np.median(foldYnoSE)
+        elif foldX[i]>(np.max(foldXnoSE)-tdur/per/2):
+            signal[i]=np.median(foldYnoSE)
         else:    
             signal[i]=np.mean(foldYnoSE[(foldXnoSE>=foldXnoSE[i]-tdur/per/2) & (foldXnoSE<=foldXnoSE[i]+tdur/per/2)])
-    
+    signal=1-signal
     falseAlarmFold=np.sqrt(2)*special.erfcinv(1/np.float(len(signal)))
-    signalMax=np.min(signal)
-    signalAvg=np.median(signal[signal>signalMax])
-    signalSD=mad_std(signal[signal>signalMax])
-    
+    signalMax=np.max(signal)
+    signalAvg=np.median(signal[signal<signalMax])
+    signalSD=mad_std(signal[signal<signalMax])
+
     if np.isnan(falseAlarm):
-        params.uniquenessFP=True
-    elif signalMax<signalAvg-falseAlarmFold*signalSD:
-        params.uniquenessFP=True
+        params.uniqueFP=True
+    elif signalTrue<signalAvg+falseAlarmFold*signalSD:
+        params.uniqueFP=True
     elif falseAlarm>thershold:
-        params.uniquenessFP=True   
+        params.uniqueFP=True 
     else:    
-        params.uniquenessFP=False
+        params.uniqueFP=False
     return params
     
 
-def check_SE(params):
+def secEclipse(params):
     per=params.tlsOut.period
     tdur=params.tlsOut.duration
     foldY=params.tlsOut.folded_y
@@ -194,21 +203,21 @@ def check_SE(params):
     if 0.1*depth<seDepth:
         if fit_b>=.9:
             params.SE_found=True
-            params.SeFP=True
+            params.secEclipseFP=True
         else:
             params.SE_found=True
-            params.SeFP=False
+            params.secEclipseFP=False
     elif seDepth>3*seDepthsd:
-        params.SeFP=False
+        params.secEclipseFP=False
         params.SE_found=True
         
     else:
-         params.SeFP=False
+         params.secEclipseFP=False
          params.SE_found=False
     return params
 
 
-def phase_coverage(params):
+def phaseCover(params):
 
     fit_P=params.tlsOut.period
     fit_t0=params.tlsOut.T0
@@ -237,7 +246,7 @@ def phase_coverage(params):
         
     return params 
 
-def tdur_max(params):
+def tranDur(params):
     fit_P=params.tlsOut.period
     fit_t0=params.tlsOut.T0
     fit_tdur=params.tlsOut.duration
@@ -245,9 +254,9 @@ def tdur_max(params):
     if fit_P<.5:
         params.tdurFP=True
     elif fit_tdur/fit_P>.1:
-        params.tdurFP=True
+        params.tranDurFP=True
     else:
-        params.tdurFP=False
+        params.tranDurFP=False
         
     return params    
                    
\ No newline at end of file
